@@ -46,7 +46,7 @@ public class FileHeaderFactory {
 
     String fileName = validateAndGetFileName(zipParameters.getFileNameInZip());
     fileHeader.setFileName(fileName);
-    fileHeader.setFileNameLength(determineFileNameLength(fileName));
+    fileHeader.setFileNameLength(determineFileNameLength(fileName, charset));
     fileHeader.setDiskNumberStart(isSplitZip ? currentDiskNumberStart : 0);
 
     if (zipParameters.getLastModifiedFileTime() > 0) {
@@ -58,7 +58,12 @@ public class FileHeaderFactory {
     //For files added by this library, this attribute will be set after closeEntry is done
     fileHeader.setExternalFileAttributes(new byte[4]);
     fileHeader.setDirectory(isZipEntryDirectory(fileName));
-    fileHeader.setUncompressedSize(zipParameters.getEntrySize());
+
+    if (zipParameters.isWriteExtendedLocalFileHeader() && zipParameters.getEntrySize() == -1) {
+      fileHeader.setUncompressedSize(0);
+    } else {
+      fileHeader.setUncompressedSize(zipParameters.getEntrySize());
+    }
 
     if (zipParameters.isEncryptFiles() && zipParameters.getEncryptionMethod() == EncryptionMethod.ZIP_STANDARD) {
       fileHeader.setCrc(zipParameters.getEntryCRC());
@@ -156,7 +161,7 @@ public class FileHeaderFactory {
     return aesExtraDataRecord;
   }
 
-  private int determineFileNameLength(String fileName) {
-    return fileName.getBytes(InternalZipConstants.CHARSET_UTF_8).length;
+  private int determineFileNameLength(String fileName, Charset charset) {
+    return fileName.getBytes(charset).length;
   }
 }
