@@ -33,7 +33,6 @@ import net.lingala.zip4j.model.enums.AesKeyStrength;
 import net.lingala.zip4j.model.enums.AesVersion;
 import net.lingala.zip4j.model.enums.CompressionMethod;
 import net.lingala.zip4j.model.enums.EncryptionMethod;
-import net.lingala.zip4j.util.InternalZipConstants;
 import net.lingala.zip4j.util.RawIO;
 
 import java.io.IOException;
@@ -61,10 +60,16 @@ public class HeaderReader {
   private byte[] intBuff = new byte[4];
 
   public ZipModel readAllHeaders(RandomAccessFile zip4jRaf, Charset charset) throws IOException {
+
+    if (zip4jRaf.length() < ENDHDR) {
+      throw new ZipException("Zip file size less than minimum expected zip file size. " +
+          "Probably not a zip file or a corrupted zip file");
+    }
+
     zipModel = new ZipModel();
 
     try {
-      zipModel.setEndOfCentralDirectoryRecord(readEndOfCentralDirectoryRecord(zip4jRaf, rawIO));
+      zipModel.setEndOfCentralDirectoryRecord(readEndOfCentralDirectoryRecord(zip4jRaf, rawIO, charset));
     } catch (ZipException e){
       throw e;
     } catch (IOException e) {
@@ -89,7 +94,7 @@ public class HeaderReader {
     return zipModel;
   }
 
-  private EndOfCentralDirectoryRecord readEndOfCentralDirectoryRecord(RandomAccessFile zip4jRaf, RawIO rawIO)
+  private EndOfCentralDirectoryRecord readEndOfCentralDirectoryRecord(RandomAccessFile zip4jRaf, RawIO rawIO, Charset charset)
       throws IOException {
     long pos = zip4jRaf.length() - ENDHDR;
 
@@ -123,7 +128,7 @@ public class HeaderReader {
     if (commentLength > 0) {
       byte[] commentBuf = new byte[commentLength];
       zip4jRaf.readFully(commentBuf);
-      endOfCentralDirectoryRecord.setComment(new String(commentBuf, InternalZipConstants.CHARSET_UTF_8));
+      endOfCentralDirectoryRecord.setComment(new String(commentBuf, charset));
     } else {
       endOfCentralDirectoryRecord.setComment(null);
     }
