@@ -12,6 +12,7 @@ import net.lingala.zip4j.model.enums.AesVersion;
 import net.lingala.zip4j.model.enums.CompressionMethod;
 import net.lingala.zip4j.model.enums.EncryptionMethod;
 import net.lingala.zip4j.progress.ProgressMonitor;
+import net.lingala.zip4j.testutils.HeaderVerifier;
 import net.lingala.zip4j.testutils.TestUtils;
 import net.lingala.zip4j.testutils.ZipFileVerifier;
 import net.lingala.zip4j.util.BitUtils;
@@ -38,6 +39,8 @@ public class AddFilesToZipIT extends AbstractIT {
   @Rule
   public ExpectedException expectedException = ExpectedException.none();
 
+  private HeaderVerifier headerVerifier = new HeaderVerifier();
+
   @Test
   public void testAddFileAsStringParameterThrowsExceptionWhenFileDoesNotExist() throws ZipException {
     expectedException.expectMessage("File does not exist: somefile.txt");
@@ -537,6 +540,36 @@ public class AddFilesToZipIT extends AbstractIT {
     verifyFoldersInZip(fileHeaders, generatedZipFile, PASSWORD);
   }
 
+  @Test
+  public void testAddFolderWithRootFolderNameInZipAndWithoutRootFolder() throws IOException {
+    ZipParameters zipParameters = createZipParameters(EncryptionMethod.AES, AesKeyStrength.KEY_STRENGTH_256);
+    zipParameters.setIncludeRootFolder(false);
+    zipParameters.setRootFolderNameInZip("root_folder_name");
+    ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
+
+    zipFile.addFolder(TestUtils.getTestFileFromResources(""), zipParameters);
+
+    List<FileHeader> fileHeaders = getFileHeaders(generatedZipFile);
+    verifyAllFilesInZipContainsPath(fileHeaders, "root_folder_name/");
+    verifyAllFilesInZipDoesNotContainPath(fileHeaders, "root_folder_name/test-files/");
+    verifyFoldersInZip(fileHeaders, generatedZipFile, PASSWORD);
+  }
+
+  @Test
+  public void testAddFolderWithRootFolderNameInZipAndWithRootFolder() throws IOException {
+    ZipParameters zipParameters = createZipParameters(EncryptionMethod.AES, AesKeyStrength.KEY_STRENGTH_256);
+    zipParameters.setIncludeRootFolder(true);
+    zipParameters.setRootFolderNameInZip("root_folder_name");
+    ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
+
+    zipFile.addFolder(TestUtils.getTestFileFromResources(""), zipParameters);
+
+    List<FileHeader> fileHeaders = getFileHeaders(generatedZipFile);
+    verifyAllFilesInZipContainsPath(fileHeaders, "root_folder_name/");
+    verifyAllFilesInZipContainsPath(fileHeaders, "root_folder_name/test-files/");
+    verifyFoldersInZip(fileHeaders, generatedZipFile, PASSWORD);
+  }
+
   @Test
   public void testAddFolderWithProgressMonitor() throws IOException, InterruptedException {
     ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
@@ -720,6 +753,7 @@ public class AddFilesToZipIT extends AbstractIT {
     ZipFileVerifier.verifyZipFileByExtractingAllFiles(generatedZipFile, PASSWORD, outputFolder, 1);
     verifyZipFileContainsFiles(generatedZipFile, singletonList("бореиская.txt"), CompressionMethod.DEFLATE,
         EncryptionMethod.AES, AesKeyStrength.KEY_STRENGTH_256);
+    headerVerifier.verifyLocalFileHeaderUncompressedSize(generatedZipFile, "бореиская.txt", 0);
   }
 
   @Test
