@@ -22,6 +22,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 
+import static net.lingala.zip4j.testutils.TestUtils.getTestFileFromResources;
 import static net.lingala.zip4j.testutils.ZipFileVerifier.verifyZipFileByExtractingAllFiles;
 import static org.assertj.core.api.Assertions.assertThat;
 
@@ -41,6 +42,20 @@ public class CreateZipFileIT extends AbstractIT {
     ZipFileVerifier.verifyZipFileByExtractingAllFiles(generatedZipFile, outputFolder, FILES_TO_ADD.size());
   }
 
+  @Test
+  public void testCreateSplitZipFileNotSplitArchiveWithZipNameAsStringAndCharsetCp949() throws IOException {
+    String koreanFileName = "가나다.abc";
+    ZipFile zipFile = new ZipFile(generatedZipFile.getPath());
+    List<File> filesToAdd = new ArrayList<>();
+    filesToAdd.add(getTestFileFromResources(koreanFileName));
+
+    zipFile.setCharset(CHARSET_CP_949);
+    zipFile.createSplitZipFile(filesToAdd, new ZipParameters(), false, -1);
+
+    ZipFileVerifier.verifyZipFileByExtractingAllFiles(generatedZipFile, null, outputFolder, filesToAdd.size(), true, CHARSET_CP_949);
+    assertThat(zipFile.getFileHeaders().get(0).getFileName()).isEqualTo(koreanFileName);
+  }
+
   @Test
   public void testCreateSplitZipFileNotSplitArchiveWithZipNameAsStringWithAESEncryption256() throws IOException {
     ZipParameters zipParameters = createZipParameters(EncryptionMethod.AES,
