@@ -11,6 +11,7 @@ import org.junit.rules.ExpectedException;
 
 import java.io.ByteArrayInputStream;
 import java.io.File;
+import java.io.IOException;
 import java.util.Collections;
 
 import static org.assertj.core.api.Assertions.assertThat;
@@ -398,6 +399,13 @@ public class ZipFileTest {
     zipFile.extractFile("", "SOME_DESTINATION");
   }
 
+  @Test
+  public void testGetFileHeadersReturnsEmptyListWhenZipFileDoesNotExist() throws ZipException {
+    File mockFile = mockFile(false);
+    ZipFile zipFile = new ZipFile(mockFile);
+    assertThat(zipFile.getFileHeaders()).isEmpty();
+  }
+
   @Test
   public void testGetFileHeaderThrowsExceptionWhenFileNameIsNull() throws ZipException {
     expectedException.expectMessage("input file name is emtpy or null, cannot get FileHeader");
@@ -481,7 +489,7 @@ public class ZipFileTest {
   }
 
   @Test
-  public void testGetInputStreamWhenFileHeaderIsNullThrowsException() throws ZipException {
+  public void testGetInputStreamWhenFileHeaderIsNullThrowsException() throws IOException {
     expectedException.expectMessage("FileHeader is null, cannot get InputStream");
     expectedException.expect(ZipException.class);
 
