@@ -4,11 +4,13 @@ import net.lingala.zip4j.exception.ZipException;
 import net.lingala.zip4j.model.CentralDirectory;
 import net.lingala.zip4j.model.FileHeader;
 import net.lingala.zip4j.model.ZipModel;
+import net.lingala.zip4j.util.InternalZipConstants;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.ExpectedException;
 
-import java.nio.charset.StandardCharsets;
+import java.io.UnsupportedEncodingException;
+import java.nio.charset.Charset;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -215,18 +217,18 @@ public class HeaderUtilTest {
   @Test
   public void testDecodeStringWithCharsetForUtf8() {
     String utf8StringToEncode = "asdäüöö";
-    byte[] utf8EncodedBytes = utf8StringToEncode.getBytes(StandardCharsets.UTF_8);
+    byte[] utf8EncodedBytes = utf8StringToEncode.getBytes(InternalZipConstants.CHARSET_UTF_8);
 
-    assertThat(HeaderUtil.decodeStringWithCharset(utf8EncodedBytes, true)).isEqualTo(utf8StringToEncode);
+    assertThat(HeaderUtil.decodeStringWithCharset(utf8EncodedBytes, true, null)).isEqualTo(utf8StringToEncode);
 
   }
 
   @Test
   public void testDecodeStringWithCharsetWithoutUtf8ForUtf8String() {
     String utf8StringToEncode = "asdäüöö";
-    byte[] utf8EncodedBytes = utf8StringToEncode.getBytes(StandardCharsets.UTF_8);
+    byte[] utf8EncodedBytes = utf8StringToEncode.getBytes(InternalZipConstants.CHARSET_UTF_8);
 
-    assertThat(HeaderUtil.decodeStringWithCharset(utf8EncodedBytes, false)).isNotEqualTo(utf8StringToEncode);
+    assertThat(HeaderUtil.decodeStringWithCharset(utf8EncodedBytes, false, null)).isNotEqualTo(utf8StringToEncode);
 
   }
 
@@ -235,10 +237,34 @@ public class HeaderUtilTest {
     String plainString = "asdasda234234";
     byte[] plainEncodedBytes = plainString.getBytes();
 
-    assertThat(HeaderUtil.decodeStringWithCharset(plainEncodedBytes, false)).isEqualTo(plainString);
+    assertThat(HeaderUtil.decodeStringWithCharset(plainEncodedBytes, false, null)).isEqualTo(plainString);
 
   }
 
+  @Test
+  public void testDecodeStringWithCharsetWithISO8859AndFinnishChars() throws UnsupportedEncodingException {
+    String finnishString = "asdäüöö";
+    byte[] plainEncodedBytes = finnishString.getBytes("ISO-8859-1");
+
+    assertThat(HeaderUtil.decodeStringWithCharset(plainEncodedBytes, false, Charset.forName("ISO-8859-1"))).isEqualTo(finnishString);
+  }
+
+  @Test
+  public void testDecodeStringWithCharsetWithUTF8CharsetAndKoreanChars() {
+    String koreanString = "가나다";
+    byte[] plainEncodedBytes = koreanString.getBytes(InternalZipConstants.CHARSET_UTF_8);
+
+    assertThat(HeaderUtil.decodeStringWithCharset(plainEncodedBytes, true, null)).isEqualTo(koreanString);
+  }
+
+  @Test
+  public void testDecodeStringWithCharsetWithNullCharsetAndEnglishChars() {
+    String englishString = "asdasda234234";
+    byte[] plainEncodedBytes = englishString.getBytes();
+
+    assertThat(HeaderUtil.decodeStringWithCharset(plainEncodedBytes, false, null)).isEqualTo(englishString);
+  }
+
   private List<FileHeader> generateFileHeaderWithFileNames(String fileNamePrefix, int numberOfEntriesToAdd) {
     List<FileHeader> fileHeaders = new ArrayList<>();
     for (int i = 0; i < numberOfEntriesToAdd; i++) {
