@@ -30,6 +30,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.RandomAccessFile;
+import java.nio.charset.Charset;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -63,11 +64,11 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream);
+      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(InputStream inputStream = new FileInputStream(headersFile)) {
-      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream);
+      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream, InternalZipConstants.CHARSET_UTF_8);
       verifyLocalFileHeader(readLocalFileHeader, FILE_NAME_PREFIX + "LFH", COMPRESSED_SIZE, UNCOMPRESSED_SIZE);
     }
   }
@@ -80,15 +81,15 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream);
+      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(InputStream inputStream = new FileInputStream(headersFile)) {
-      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream);
+      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream, InternalZipConstants.CHARSET_UTF_8);
       verifyLocalFileHeader(readLocalFileHeader, FILE_NAME_PREFIX + "LFH", COMPRESSED_SIZE_ZIP64,
           UNCOMPRESSED_SIZE_ZIP64);
       verifyZip64ExtendedInfo(readLocalFileHeader.getZip64ExtendedInfo(), COMPRESSED_SIZE_ZIP64,
-          UNCOMPRESSED_SIZE_ZIP64, 0, 0);
+          UNCOMPRESSED_SIZE_ZIP64, -1, -1);
     }
 
     verifyEntrySizesIsMaxValueInLFHWhenZip64Format(headersFile);
@@ -107,9 +108,27 @@ public class HeaderWriterIT extends AbstractIT {
   }
 
   @Test
-  public void testWriteLocalFileHeaderJapaneseCharactersInFileNameWithoutUtf8ShouldNotMatch()
+  public void testWriteLocalFileHeaderJapaneseCharactersInFileNameWithoutUtf8ShouldMatch()
       throws IOException {
-    testWriteLocalFileHeaderWithFileName("公ゃ的年社", false, false);
+    testWriteLocalFileHeaderWithFileName("公ゃ的年社", false, true);
+  }
+
+  @Test
+  public void testWriteLocalFileHeaderJapaneseCharactersInFileNameWithCharsetMs932ShouldMatch()
+          throws IOException {
+    testWriteLocalFileHeaderWithFileNameAndCharset("公ゃ的年社", false, true, CHARSET_MS_932);
+  }
+
+  @Test
+  public void testWriteLocalFileHeaderJapaneseCharactersInFileNameWithUTF8CharsetWithUtf8ShouldMatch()
+          throws IOException {
+    testWriteLocalFileHeaderWithFileNameAndCharset("公ゃ的年社", true, true, InternalZipConstants.CHARSET_UTF_8);
+  }
+
+  @Test
+  public void testWriteLocalFileHeaderJapaneseCharactersInFileNameWithUTF8CharsetWithoutUtf8ShouldMatch()
+          throws IOException {
+    testWriteLocalFileHeaderWithFileNameAndCharset("公ゃ的年社", false, true, InternalZipConstants.CHARSET_UTF_8);
   }
 
   @Test
@@ -171,7 +190,7 @@ public class HeaderWriterIT extends AbstractIT {
     expectedException.expect(ZipException.class);
     expectedException.expectMessage("input parameters is null, cannot finalize zip file");
 
-    headerWriter.finalizeZipFile(null, new FileOutputStream(temporaryFolder.newFile()));
+    headerWriter.finalizeZipFile(null, new FileOutputStream(temporaryFolder.newFile()), InternalZipConstants.CHARSET_UTF_8);
   }
 
   @Test
@@ -179,7 +198,7 @@ public class HeaderWriterIT extends AbstractIT {
     expectedException.expect(ZipException.class);
     expectedException.expectMessage("input parameters is null, cannot finalize zip file");
 
-    headerWriter.finalizeZipFile(new ZipModel(), null);
+    headerWriter.finalizeZipFile(new ZipModel(), null, InternalZipConstants.CHARSET_UTF_8);
   }
 
   @Test
@@ -188,11 +207,11 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.finalizeZipFile(zipModel, outputStream);
+      headerWriter.finalizeZipFile(zipModel, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(headersFile, RandomAccessFileMode.READ.getValue())) {
-      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile);
+      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile, null);
       verifyZipModel(readZipModel, 10);
 
       for (FileHeader fileHeader : readZipModel.getCentralDirectory().getFileHeaders()) {
@@ -209,11 +228,11 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.finalizeZipFile(zipModel, outputStream);
+      headerWriter.finalizeZipFile(zipModel, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(headersFile, RandomAccessFileMode.READ.getValue())) {
-      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile);
+      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile, null);
       verifyZipModel(readZipModel, 10, COMPRESSED_SIZE_ZIP64, UNCOMPRESSED_SIZE_ZIP64, true);
 
       List<FileHeader> fileHeaders = readZipModel.getCentralDirectory().getFileHeaders();
@@ -232,11 +251,11 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.finalizeZipFile(zipModel, outputStream);
+      headerWriter.finalizeZipFile(zipModel, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(headersFile, RandomAccessFileMode.READ.getValue())) {
-      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile);
+      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile, null);
       verifyZipModel(readZipModel, 10);
 
       for (FileHeader fileHeader : readZipModel.getCentralDirectory().getFileHeaders()) {
@@ -254,11 +273,11 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(SplitOutputStream outputStream = new SplitOutputStream(headersFile, 65536)) {
-      headerWriter.finalizeZipFile(zipModel, outputStream);
+      headerWriter.finalizeZipFile(zipModel, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(headersFile, RandomAccessFileMode.READ.getValue())) {
-      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile);
+      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile, null);
       verifyZipModel(readZipModel, 10, COMPRESSED_SIZE_ZIP64, UNCOMPRESSED_SIZE_ZIP64, true);
 
       List<FileHeader> fileHeaders = readZipModel.getCentralDirectory().getFileHeaders();
@@ -276,11 +295,11 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(CountingOutputStream outputStream = new CountingOutputStream(new SplitOutputStream(headersFile, 65536))) {
-      headerWriter.finalizeZipFile(zipModel, outputStream);
+      headerWriter.finalizeZipFile(zipModel, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(headersFile, RandomAccessFileMode.READ.getValue())) {
-      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile);
+      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile, null);
       verifyZipModel(readZipModel, 10, COMPRESSED_SIZE_ZIP64, UNCOMPRESSED_SIZE_ZIP64, true);
 
       List<FileHeader> fileHeaders = readZipModel.getCentralDirectory().getFileHeaders();
@@ -297,7 +316,7 @@ public class HeaderWriterIT extends AbstractIT {
     expectedException.expect(ZipException.class);
     expectedException.expectMessage("input parameters is null, cannot finalize zip file");
 
-    headerWriter.finalizeZipFileWithoutValidations(null, new FileOutputStream(temporaryFolder.newFile()));
+    headerWriter.finalizeZipFileWithoutValidations(null, new FileOutputStream(temporaryFolder.newFile()), null);
   }
 
   @Test
@@ -306,7 +325,7 @@ public class HeaderWriterIT extends AbstractIT {
     expectedException.expect(ZipException.class);
     expectedException.expectMessage("input parameters is null, cannot finalize zip file");
 
-    headerWriter.finalizeZipFileWithoutValidations(new ZipModel(), null);
+    headerWriter.finalizeZipFileWithoutValidations(new ZipModel(), null, null);
   }
 
   @Test
@@ -315,11 +334,11 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.finalizeZipFileWithoutValidations(zipModel, outputStream);
+      headerWriter.finalizeZipFileWithoutValidations(zipModel, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(headersFile, RandomAccessFileMode.READ.getValue())) {
-      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile);
+      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile, InternalZipConstants.CHARSET_UTF_8);
       verifyZipModel(readZipModel, 10);
 
       for (FileHeader fileHeader : readZipModel.getCentralDirectory().getFileHeaders()) {
@@ -336,11 +355,11 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.finalizeZipFileWithoutValidations(zipModel, outputStream);
+      headerWriter.finalizeZipFileWithoutValidations(zipModel, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(RandomAccessFile randomAccessFile = new RandomAccessFile(headersFile, RandomAccessFileMode.READ.getValue())) {
-      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile);
+      ZipModel readZipModel = headerReader.readAllHeaders(randomAccessFile, InternalZipConstants.CHARSET_UTF_8);
       verifyZipModel(readZipModel, 10, COMPRESSED_SIZE_ZIP64, UNCOMPRESSED_SIZE_ZIP64, true);
 
       List<FileHeader> fileHeaders = readZipModel.getCentralDirectory().getFileHeaders();
@@ -374,7 +393,7 @@ public class HeaderWriterIT extends AbstractIT {
     createAndUpdateLocalFileHeader(headersFile, COMPRESSED_SIZE, UNCOMPRESSED_SIZE, 23423);
 
     try (InputStream inputStream = new FileInputStream(headersFile)) {
-      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream);
+      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream, InternalZipConstants.CHARSET_UTF_8);
       assertThat(readLocalFileHeader.getCompressedSize()).isEqualTo(COMPRESSED_SIZE + 100);
       assertThat(readLocalFileHeader.getUncompressedSize()).isEqualTo(UNCOMPRESSED_SIZE + 100);
       assertThat(readLocalFileHeader.getCrc()).isEqualTo(23423);
@@ -388,12 +407,12 @@ public class HeaderWriterIT extends AbstractIT {
     createAndUpdateLocalFileHeader(headersFile, COMPRESSED_SIZE_ZIP64, UNCOMPRESSED_SIZE_ZIP64, 546423);
 
     try (InputStream inputStream = new FileInputStream(headersFile)) {
-      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream);
+      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream, InternalZipConstants.CHARSET_UTF_8);
       assertThat(readLocalFileHeader.getCompressedSize()).isEqualTo(COMPRESSED_SIZE_ZIP64 + 100);
       assertThat(readLocalFileHeader.getUncompressedSize()).isEqualTo(UNCOMPRESSED_SIZE_ZIP64 + 100);
       assertThat(readLocalFileHeader.getCrc()).isEqualTo(546423);
       verifyZip64ExtendedInfo(readLocalFileHeader.getZip64ExtendedInfo(), COMPRESSED_SIZE_ZIP64 + 100,
-          UNCOMPRESSED_SIZE_ZIP64 + 100, 0, 0);
+          UNCOMPRESSED_SIZE_ZIP64 + 100, -1, -1);
     }
 
     verifyEntrySizesIsMaxValueInLFHWhenZip64Format(headersFile);
@@ -408,12 +427,13 @@ public class HeaderWriterIT extends AbstractIT {
     localFileHeaderToWrite.setCrc(10);
 
     try (OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream);
+      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try (SplitOutputStream splitOutputStream = new SplitOutputStream(headersFile)) {
       FileHeader fileHeader = createFileHeaders(1, compressedSize + 100, uncompressedSize + 100).get(0);
-      fileHeader.setFileNameLength(fileHeader.getFileName().length());
+      fileHeader.setFileName(localFileHeaderToWrite.getFileName());
+      fileHeader.setFileNameLength(fileHeader.getFileName().getBytes(InternalZipConstants.CHARSET_UTF_8).length);
       fileHeader.setCrc(crc);
       headerWriter.updateLocalFileHeader(fileHeader, zipModel, splitOutputStream);
     }
@@ -488,11 +508,11 @@ public class HeaderWriterIT extends AbstractIT {
     File headersFile = temporaryFolder.newFile();
 
     try(OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream);
+      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream, InternalZipConstants.CHARSET_UTF_8);
     }
 
     try(InputStream inputStream = new FileInputStream(headersFile)) {
-      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream);
+      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream, InternalZipConstants.CHARSET_UTF_8);
       assertThat(readLocalFileHeader.getEncryptionMethod()).isEqualTo(EncryptionMethod.AES);
       verifyAesExtraDataRecord(readLocalFileHeader.getAesExtraDataRecord(), aesKeyStrength, aesVersion);
     }
@@ -520,17 +540,22 @@ public class HeaderWriterIT extends AbstractIT {
 
   private void testWriteLocalFileHeaderWithFileName(String fileNameSuffix, boolean useUtf8,
                                                     boolean expectFileNamesToMatch) throws IOException {
+    testWriteLocalFileHeaderWithFileNameAndCharset(fileNameSuffix, useUtf8, expectFileNamesToMatch, InternalZipConstants.CHARSET_UTF_8);
+  }
+
+  private void testWriteLocalFileHeaderWithFileNameAndCharset(String fileNameSuffix, boolean useUtf8,
+                                                    boolean expectFileNamesToMatch, Charset charset) throws IOException {
     ZipModel zipModel = createZipModel(10);
     LocalFileHeader localFileHeaderToWrite = createLocalFileHeader(fileNameSuffix, COMPRESSED_SIZE, UNCOMPRESSED_SIZE,
         useUtf8);
     File headersFile = temporaryFolder.newFile();
 
     try(OutputStream outputStream = new FileOutputStream(headersFile)) {
-      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream);
+      headerWriter.writeLocalFileHeader(zipModel, localFileHeaderToWrite, outputStream, charset);
     }
 
     try(InputStream inputStream = new FileInputStream(headersFile)) {
-      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream);
+      LocalFileHeader readLocalFileHeader = headerReader.readLocalFileHeader(inputStream, charset);
       if (expectFileNamesToMatch) {
         assertThat(readLocalFileHeader.getFileName()).isEqualTo(FILE_NAME_PREFIX + fileNameSuffix);
       } else {
