@@ -248,7 +248,26 @@ public class FileUtilsTest {
 
   @Test
   public void testGetRelativeFileNameWhenRootFoldersAreNull() throws ZipException {
-    assertThat(FileUtils.getRelativeFileName("somefile.txt", null)).isEqualTo("somefile.txt");
+    assertThat(FileUtils.getRelativeFileName("somefile.txt", null, null)).isEqualTo("somefile.txt");
+  }
+
+  @Test
+  public void testGetRelativeFileWithRootFolderNameInZip() throws ZipException {
+    String expectedRootFolder = "rootfolder" + InternalZipConstants.FILE_SEPARATOR + "somefile.txt";
+    assertThat(FileUtils.getRelativeFileName("somefile.txt", null, "rootfolder")).isEqualTo(expectedRootFolder);
+  }
+
+  @Test
+  public void testGetRelativeFileWithRootFolderNameInZipWithFileSeparator() throws ZipException {
+    String expectedRootFolder = "rootfolder" + InternalZipConstants.FILE_SEPARATOR + "somefile.txt";
+    assertThat(FileUtils.getRelativeFileName("somefile.txt", null, "rootfolder" + File.separator))
+        .isEqualTo(expectedRootFolder);
+  }
+
+  @Test
+  public void testGetRelativeFileWithRootFolderNameInZipWithSeparatorsInName() throws ZipException {
+    String expectedRootFolder = "rootfolder" + InternalZipConstants.FILE_SEPARATOR + "somefile.txt";
+    assertThat(FileUtils.getRelativeFileName("somefile.txt", null, "rootfolder\\")).isEqualTo(expectedRootFolder);
   }
 
   @Test
